# translator test project
for testing purposes only

# dummy instruction
    Translates given text using Google Translator.

    Pass the languages by the name or by abbreviation, eg. 'english' or 'en'.
    Pass 'auto' for automatic detection of source language.